import matplotlib.pyplot as plt
import numpy as np
import pandas as pd
import matplotlib as mpl
import cmocean
#plt.style.use("mundus")

data_background = np.genfromtxt("M23_RFsweep-stripe_disk7p2GHz_intensity-map_disk-OFF_stripe-OFF.txt")
data_ds = np.genfromtxt("M23_RFsweep-stripe_disk7p2GHz_intensity-map_disk-ON_stripe-ON.txt") #ds both stripe and disk excited
data_s = np.genfromtxt("M23_RFsweep-stripe_disk7p2GHz_intensity-map_disk-OFF_stripe-ON.txt") # s only stripe excited
data_d = np.genfromtxt("M23_RFsweep-stripe_disk7p2GHz_intensity-map_disk-ON_stripe-OFF.txt") # d only disk excited

data_ds_norm = data_ds - data_background
data_s_norm = data_s - data_background
data_d_norm = data_d - data_background



# calculate what needs to be cut off in the plots to have axes numbers match the actual data:
print(data_ds_norm.shape)
xmax = 5
xmin = 3.5
ymin = 9.713
ymax = -2.25

dx = (xmax - xmin) / data_ds_norm.shape[1]
dy = (ymax - ymin) / data_ds_norm.shape[0]


#generate figure for stripe and disk excited without axes
fig_ds_norm_1 = plt.figure()
ax_ds_norm_1 = plt.Axes(fig_ds_norm_1, [0, 0, 1, 1])
ax_ds_norm_1.set_axis_off()
fig_ds_norm_1.add_axes(ax_ds_norm_1)

ax_ds_norm_1.imshow(data_ds_norm, aspect="auto", norm=mpl.colors.LogNorm(vmin=1, vmax=3500),
            cmap=cmocean.cm.ice_r, extent=[xmin - dx/2, xmax + dx/2, ymin - dy/2, ymax + dy/2]
            ) #imshow always 2D data
ax_ds_norm_1.set(ylim = [2, 8], xlim = [xmin, xmax]
            )
#generate figure for stripe and disk excited with axes
fig_ds_norm_2, ax_ds_norm_2 = plt.subplots()

ax_ds_norm_2.imshow(data_ds_norm, aspect="auto", norm=mpl.colors.LogNorm(vmin=1, vmax=3500),
            cmap=cmocean.cm.ice_r, extent=[xmin - dx/2, xmax + dx/2, ymin - dy/2, ymax + dy/2]
            ) #imshow always 2D data
ax_ds_norm_2.set(ylim=[2, 8], ylabel = "BLS frequency (GHz)", xlabel = "Excitation frequency of stripe (GHz)",
            xlim = [xmin, xmax]
            )
fig_ds_norm_2.tight_layout()

#generate figure for only stripe excited without axes
fig_s_norm_1 = plt.figure()
ax_s_norm_1 = plt.Axes(fig_s_norm_1, [0, 0, 1, 1])
ax_s_norm_1.set_axis_off()
fig_s_norm_1.add_axes(ax_s_norm_1)

ax_s_norm_1.imshow(data_s_norm, aspect="auto", norm=mpl.colors.LogNorm(vmin=1, vmax=3500),
            cmap=cmocean.cm.ice_r, extent=[xmin - dx/2, xmax + dx/2, ymin - dy/2, ymax + dy/2]
            ) #imshow always 2D data
ax_s_norm_1.set(ylim = [2, 8], xlim = [xmin, xmax]
            )
#generate figure for only stripe excited with axes
fig_s_norm_2, ax_s_norm_2 = plt.subplots()

ax_s_norm_2.imshow(data_s_norm, aspect="auto", norm=mpl.colors.LogNorm(vmin=1, vmax=3500),
            cmap=cmocean.cm.ice_r, extent=[xmin - dx/2, xmax + dx/2, ymin - dy/2, ymax + dy/2]
            ) #imshow always 2D data
ax_s_norm_2.set(ylim=[2, 8], ylabel = "BLS frequency (GHz)", xlabel = "Excitation frequency of stripe (GHz)",
            xlim = [xmin, xmax]
            )
fig_s_norm_2.tight_layout()

#generate figure for only disk excited without axes
fig_d_norm_1 = plt.figure()
ax_d_norm_1 = plt.Axes(fig_d_norm_1, [0, 0, 1, 1])
ax_d_norm_1.set_axis_off()
fig_d_norm_1.add_axes(ax_d_norm_1)

ax_d_norm_1.imshow(data_d_norm, aspect="auto", norm=mpl.colors.LogNorm(vmin=1, vmax=3500),
            cmap=cmocean.cm.ice_r, extent=[xmin - dx/2, xmax + dx/2, ymin - dy/2, ymax + dy/2]
            ) #imshow always 2D data
ax_d_norm_1.set(ylim = [2, 8], xlim = [xmin, xmax]
            )
#generate figure for only stripe excited with axes
fig_d_norm_2, ax_d_norm_2 = plt.subplots()

ax_d_norm_2.imshow(data_d_norm, aspect="auto", norm=mpl.colors.LogNorm(vmin=1, vmax=3500),
            cmap=cmocean.cm.ice_r, extent=[xmin - dx/2, xmax + dx/2, ymin - dy/2, ymax + dy/2]
            ) #imshow always 2D data
ax_d_norm_2.set(ylim=[2, 8], ylabel = "BLS frequency (GHz)", xlabel = "Excitation frequency of stripe (GHz)",
            xlim = [xmin, xmax]
            )
fig_d_norm_2.tight_layout()


fig_spectra, ax_spectra = plt.subplots()
f = np.linspace(ymax, ymin, data_ds_norm.shape[0])
ax_spectra.set(ylim=[0, None])
ax_spectra.plot(f, data_ds[:,46])
ax_spectra.plot(f, data_s[:,46])
ax_spectra.plot(f, data_d[:,46])



fig_ds_norm_1.savefig("data_disk-ON_stripe-ON_norm_1.png")
fig_ds_norm_2.savefig("data_disk-ON_stripe-ON_norm_2.png")
fig_d_norm_1.savefig("data_only-disk_norm_1.png")
fig_d_norm_2.savefig("data_only-disk_norm_2.png")
fig_s_norm_1.savefig("data_only_stripe_norm_1.png")
fig_s_norm_2.savefig("data_only_stripe_norm_2.png")

plt.show()
