Nx := 1024
Ny := 1024
Nz := 1

//EdgeSmooth = 8

D := 5.1e-6
th := 50e-9

world := 10e-6


// stripe
pitch := 100e-9
width := 2e-6
length := 10e-6

boundary := -100e-9
disk_offset_y := 0.5*(pitch + D)
stripe_offset_y := -0.5*(pitch + width)

//SetPBC(8,0,0)
SetGridSize(Nx,Ny,Nz)
SetCellSize(length/Nx,2*(pitch + D)/Ny,th/Nz)

Msat  = 810e3
Aex   = 13e-12
alpha = 0.007
gammaLL = 1.86e11


layout := ImageShape("layout_10um_10um.png")

SetGeom(layout)


upperhalf := yrange(boundary,inf)
lowerhalf := yrange(-inf,boundary)


left_corner := ImageShape("mask_left_corner.png")
right_corner := ImageShape("mask_right_corner.png")
antenna := ImageShape("mask_antenna.png")

m.setInShape(upperhalf, Vortex(-1,1).transl(0, world/4,0))
m.setInShape(lowerhalf, uniform(-1,0,0))

m.setInShape(right_corner, uniform(-1,1,0))
m.setInShape(left_corner, uniform(-1,-1,0))

DefRegion(3,left_corner)
DefRegion(4,right_corner)
frozenspins.SetRegion(3, 1)
frozenspins.SetRegion(4, 1)


relax()
saveas(m, "relax.ovf")

f := 6.1e9
omega := 2 * pi * f

f_stripe := 4e9
omega_stripe := 2 * pi * f_stripe
b_RF_stripe := 10e-3


mu := 4*pi*1e-7
Current := 1000e-9
By := 0.0
Bz := 0.0
Bmag := 0.0
Bangle := 0.0


mask_right := newVectorMask(Nx, Ny, Nz)
a := 90e-9 //width of the antenna
b := 100e-9 //thickness of the antenna
theta_right := pi/4 //in-plane angle of the antenna, pi/2 means in Y direction
sizez := th // this was the height of my sample in z direction
length_antenna := 5e-6
x_shift := 3.66e-6
y_shift := -3.85e-6
z_shift := sizez/2 + b/2 + 1e-9
for i := 0; i < Nx; i++ {
     for j := 0; j < Ny; j++ {
         for k := 0; k < Nz; k++ {
            r := index2coord(i, j, k)
            x := r.X()
            y := r.Y()
            z := r.Z()
            x = x - x_shift
            y = y - y_shift
            z = z - z_shift
            r0 := sqrt(pow(x, 2) + pow(y, 2))
            angle_0 := atan2(y, x) - theta_right
            y = r0 * sin(angle_0)
            x = r0 * cos(angle_0)
            By = 1000 * ((-mu) / (8 * pi * a * b)) * ((a-y)*(0.5*log(((pow(b-z,
2))+(pow(a-y, 2)))/((pow(-b-z, 2))+(pow(a-y,
2))))+((b-z)/(a-y))*atan(((a-y)/(b-z)))-((-b-z)/(a-y))*atan(((a-y)/(-b-z)))) -
(-a-y)*(0.5*log(((pow(b-z, 2))+(pow(-a-y, 2)))/((pow(-a-y, 2))+(pow(-b-z,
2))))+((b-z)/(-a-y))*atan(((-a-y)/(b-z)))-((-b-z)/(-a-y))*atan(((-a-y)/(-b-z)))))

            Bz = -1000 * ((-mu) / (8 * pi * a * b)) * ((b-z)*(0.5*log(((pow(a-y,
2))+(pow(b-z, 2)))/((pow(-a-y, 2))+(pow(b-z,
2))))+((a-y)/(b-z))*atan(((b-z)/(a-y)))-((-a-y)/(b-z))*atan(((b-z)/(-a-y)))) -
(-b-z)*(0.5*log(((pow(a-y, 2))+(pow(-b-z, 2)))/((pow(-b-z, 2))+(pow(-a-y,
2))))+((a-y)/(-b-z))*atan(((-b-z)/(a-y)))-((-a-y)/(-b-z))*atan(((-b-z)/(-a-y)))))
            Bmag = sqrt(pow(By, 2) + pow(Bz, 2))
            Bangle = atan(Bz / By)
            mask_right.setVector(i, j, k, vector(-By*sin(theta_right), By*cos(theta_right), Bz))
           }
        }
}

mask_left := newVectorMask(Nx, Ny, Nz)
x_shift_left := -3.66e-6
theta_left := -pi/4 //in-plane angle of the antenna, pi/2 means in Y direction

for i := 0; i < Nx; i++ {
     for j := 0; j < Ny; j++ {
         for k := 0; k < Nz; k++ {
            r := index2coord(i, j, k)
            x := r.X()
            y := r.Y()
            z := r.Z()
            x = x - x_shift_left
            y = y - y_shift
            z = z - z_shift
            r0 := sqrt(pow(x, 2) + pow(y, 2))
            angle_0 := atan2(y, x) - theta_left
            y = r0 * sin(angle_0)
            x = r0 * cos(angle_0)
            By = 1000 * ((-mu) / (8 * pi * a * b)) * ((a-y)*(0.5*log(((pow(b-z,
2))+(pow(a-y, 2)))/((pow(-b-z, 2))+(pow(a-y,
2))))+((b-z)/(a-y))*atan(((a-y)/(b-z)))-((-b-z)/(a-y))*atan(((a-y)/(-b-z)))) -
(-a-y)*(0.5*log(((pow(b-z, 2))+(pow(-a-y, 2)))/((pow(-a-y, 2))+(pow(-b-z,
2))))+((b-z)/(-a-y))*atan(((-a-y)/(b-z)))-((-b-z)/(-a-y))*atan(((-a-y)/(-b-z)))))

            Bz = -1000 * ((-mu) / (8 * pi * a * b)) * ((b-z)*(0.5*log(((pow(a-y,
2))+(pow(b-z, 2)))/((pow(-a-y, 2))+(pow(b-z,
2))))+((a-y)/(b-z))*atan(((b-z)/(a-y)))-((-a-y)/(b-z))*atan(((b-z)/(-a-y)))) -
(-b-z)*(0.5*log(((pow(a-y, 2))+(pow(-b-z, 2)))/((pow(-b-z, 2))+(pow(-a-y,
2))))+((a-y)/(-b-z))*atan(((-b-z)/(a-y)))-((-a-y)/(-b-z))*atan(((-b-z)/(-a-y)))))
            Bmag = sqrt(pow(By, 2) + pow(Bz, 2))
            Bangle = atan(Bz / By)
            mask_left.setVector(i, j, k, vector(-By*sin(theta_left), By*cos(theta_left), Bz))
           }
        }
}

B_ext.Add(mask_right,current*cos(omega_stripe*t))
B_ext.Add(mask_left,current*cos(omega_stripe*t))


TableAdd(E_total)
TableAdd(Edens_total.region(1))
TableAdd(Edens_total.region(2))
TableAdd(E_exch)
TableAdd(E_demag)
TableAdd(E_Zeeman)
TableAdd(B_ext)

tableautosave(10e-12)
autosave(m,10e-12)
run(25e-9)




Exit()
/*
DefRegion(1, disk)
DefRegion(2, stripe)

SetGeom(disk.add(stripe))

alpha = 0.007
gammaLL = 1.86e11

//m.loadfile("5umdisk_vortexneg11_light_relaxed.ovf")

m.setInShape(disk, Vortex(-1,1).transl(0, disk_offset_y,0))
m.setInShape(stripe, uniform(-1,0,0))

damping_width := 500e-9
edge1_alpha := XRange(-length/2, -length/2 + damping_width)
edge2_alpha := XRange(length/2 - damping_width, length/2)
DefRegion(3, edge1_alpha.add(edge2_alpha))
alpha.SetRegion(3, 0.2)

// frozen spins at end of stripe
frozen_width := 300e-9
edge1 := XRange(-length/2, -length/2 + frozen_width)
edge2 := XRange(length/2 - frozen_width, length/2)
DefRegion(4, edge1.add(edge2))
frozenspins.SetRegion(4, 1)




relax()
saveas(m, "relax.ovf")



osc_period := 60
Amp_disk := 0.0012
amp_stripe := 0.015

f := 6.1e9
omega := 2 * pi * f

f_stripe := 2.7e9
omega_stripe := 2 * pi * f_stripe




mask := newVectorMask(Nx, Ny, Nz)

kc := pi*Nx/world
periods := 5


for i:=0; i<Nx; i++{
    for j:=0; j<Ny/2; j++{
        for k:=0; k<Nz; k++ {
            r := index2coord(i, j, k)
            x := r.X()
            y := r.Y()
            Bz := (sin(kc*(x-periods*pi/kc))/(kc*(x-periods*pi/kc)))
            mask.setVector(i, j, k, vector(0, 0, Bz))
        }
    }
}

//B_ext=vector(0,0,Amp*sin(omega_max*((t) - 2 * 1/freq_max))/(omega_max*((t) - 2 * 1/ freq_max)))

tmax := 100e-9
//Amppert := Amp / tmax

B_ext.setRegion(1,vector(0,0,Amp_disk*sin(omega*(t))))



B_ext.Add(mask, amp_stripe*sin(omega_stripe*t))


TableAdd(E_total)
TableAdd(Edens_total.region(1))
TableAdd(Edens_total.region(2))
TableAdd(E_exch)
TableAdd(E_demag)
TableAdd(E_Zeeman)
TableAdd(B_ext)

tableautosave(10e-12)
autosave(m.region(1),10e-12)
autosave(m.region(2),10e-12)
run(tmax)
saveas(m, "m_after_100ns.ovf")
*/
