import matplotlib.pylab as plt
from rate_equations import *
from scipy.optimize import curve_fit
import cmocean
from scipy.signal import argrelextrema

plt.style.use("mundus")

t_zero = time.time()

def thermal_level(T, omega, V):
    E_therm = k_B * T
    return E_therm * gamma / (Ms * V * omega)

def delay_time(B, Gamma0, c0_crit, Nth, P):
    return -1/Gamma0*np.log(1-Gamma0*(c0_crit - np.sqrt(Nth))/(P*B))

k_B = 1.38065e-23  # J/K
temperature = 293 # K
gamma = 1.86e11  # radHz/T
L = 50e-9
R = 2.55e-6
volume = pi * R**2 * L
Ms = 810e3  # kA/m

# Gilbert damping
alpha = 0.008

# Frequencies in GHz
f0 = 7.2
f1 = 4.46
f2 = 7.2-4.46
f3 = f1
f4 = f2
f_ = np.array([f0, f1, f2, f3, f4])

omega_ = 2 * pi * f_

e0 = 2.08
e1 = 2.86
e2 = 5.13
e3 = e1
e4 = e2

omega0 = 2 * pi * f0
omega1 = 2 * pi * f1
omega2 = 2 * pi * f2
omega3 = 2 * pi * f3
omega4 = 2 * pi * f4

omega_list = [omega0, omega1, omega2, omega3, omega4]
DeltaOmega = omega0 - omega1 - omega2

# First order approximation in damping

Gamma_ = alpha * omega_

Gamma0 = alpha * omega0 * e0
Gamma1 = alpha * omega1 * e1
Gamma2 = alpha * omega2 * e2
Gamma3 = alpha * omega3 * e3
Gamma4 = alpha * omega4 * e4

Gamma_list = [Gamma0, Gamma1, Gamma2, Gamma3, Gamma4]

# initial values

n_therm_ = thermal_level(temperature, omega_*1e9, volume)

therm0 = thermal_level(temperature, omega0*1e9, volume)
print(therm0)
therm1 = thermal_level(temperature, omega1*1e9, volume)
therm2 = thermal_level(temperature, omega2*1e9, volume)
therm3 = thermal_level(temperature, omega3*1e9, volume)
therm4 = thermal_level(temperature, omega4*1e9, volume)

therm_ = [therm0, therm1, therm2, therm3, therm4]
Nth = 2.3709841203909458e-08

# b00 = 1j*sqrt(therm0)
# b10 = 1j*sqrt(therm1)
# b20 = 1j*sqrt(therm2)
# b30 = 1j*sqrt(therm3)
# b40 = 1j*sqrt(therm4)

#b0_ = np.array([b00, b10, b20, b30, b40])

b0_ = 1j*np.sqrt(n_therm_)
#b0_list = [b00, b10, b20, b30, b40]

# Three magnon scattering coefficient

V = 4.36 * 2 * np.pi # radGHz
Tkk = 300 * 2 * np.pi  # radGHz
Skk =  Tkk
c0_crit = np.sqrt(Gamma1*Gamma2)/V * np.sqrt(1+(DeltaOmega**2/(Gamma1+Gamma2)**2))

# Time in ns
tmin = 0
tmax = 200
dt = 0.001
t = np.arange(tmin, tmax, dt)
#t = np.linspace(tmin, tmax, 150)
dark = 2.3709841203909458e-08

####### excitation #######
b_crit = 0.0034

P = Gamma0*(np.abs(c0_crit) - np.sqrt(therm0))/b_crit

print("P = ", P)
# field for disk below threshold
#B = 0.005  # T
B = 0.005  # T


t0 = 15  # ns
T = 100  # ns
tau = 2  # ns
A = P * B  # T


# Make one parameter function W(t) from c_inf_window
W = partial(cinf_window, t0, T, tau, A)


t0_duplet = 15  # ns
T_duplet = 7.5  # ns
tau_duplet = 2  # ns
A_duplet = 0.002

 #0.05*P_per_mu0 * B  # np.sqrt(3e6)  # T


# Make one parameter function W(t) from c_inf_window
W_duplet = partial(cinf_window, t0_duplet, T_duplet, tau_duplet, A_duplet)

fig, ax = plt.subplots(figsize=(5,4))


Nmin = 10
Nmax = 1e6


ax.set(
    xlabel="Time, $t$ (ns)",
    ylabel="Spin-wave number, $N_{\mathbf{k}}$",
    xlim=[tmin, tmax],
    #ylim=[Nmin, Nmax],
)

#ax.fill_between(t, Nmin*np.ones_like(t), W(t)+dark, color="#DCDCDC")
#ax.semilogy(t, W(t)+dark, color="C0")
#ax.fill_between(t, Nmin*np.ones_like(t), W_duplet(t)+dark, color="#f6c2be")
#ax.plot(t, W_duplet(t)+dark, color="C2", ls="-")


W = partial(cinf_window, t0, T, tau, A)
W_ = [W, W_duplet, zero_window, W_duplet, zero_window]

print("Pre took {} s".format(time.time()-t_zero))
t_start = time.time()
b_ = odeintw(rate_equations5modes_Sterms, b0_, t, args=(*omega_list, *Gamma_list, *W_, V, Tkk, Skk,
                                                 *therm_), tcrit=t0_duplet)
t_end = time.time()
print("Computation took {} s".format(t_end - t_start))

n5_ = b_.real**2 + b_.imag**2


ax.plot(t-t0, (n5_[:, 0]) + therm0, label="$N_\mathbf{0}$",
            ls="-", c="C0")
#ax.plot(t, (n5_[:, 1] + n5_[:, 3] * np.sqrt(n5_[:, 1]*n5_[:, 3])) + dark, label="$N_+$", ls="--")

N_plus = (b_[:,1].real+b_[:,3].real)**2 + (b_[:,1].imag+b_[:,3].imag)**2


N_minus = (b_[:,2].real+b_[:,4].real)**2 + (b_[:,2].imag+b_[:,4].imag)**2
ax.plot(t-t0, N_plus + 2*therm1, label="$N_+$",
#    label="$N_{+/-}$"
            )

ax.plot(t-t0, N_minus + 2*therm2, label="$N_-$",
)
df = pd.DataFrame({"t (ns)" : t-t0,
                  "N_0" : n5_[:, 0]+therm0,
                  "N_minus" : N_minus+2*therm1,
                  "N_plus" : N_plus+2*therm2})

#df.to_csv("rate-equations_7p2GHz_only-disk-below.csv")
#df.to_csv("rate-equations_7p2GHz_only-disk-below-higher-field.csv") # 0.003 mT
#df.to_csv("rate-equations_7p2GHz_only-disk-above.csv") # 0.005 mT

#df.to_csv("rate-equations_7p2GHz_only-disk-above.csv")

#df.to_csv("rate-equations_7p2GHz_only-stripe.csv")

df.to_csv("rate-equations_7p2GHz_both-combined-above-higher-field-shortpulse.csv") # 0.005 mT + 0.002

#df.to_csv("rate-equations_7p2GHz_both-combined-higher-field.csv") # 0.003 mT + 0.002

#ax.plot(t, (n5_[:, 2] + n5_[:, 4] + np.sqrt(n5_[:, 2]*n5_[:, 4])) + dark, label="$N_-$", ls=":")

#ax.plot(t, (n5_[:, 2] + n5_[:, 4]) + dark, label="$N_-$", ls=":", c=cmap(i))
#ax.plot(np.nan,np.nan, label="$N_\mathbf{0}$", ls="-", c="k")
#ax.plot(np.nan,np.nan, label="$N_{+/-}$", ls="-.", c="k")

ax.set_xlim([-10,30])
ax.legend()
fig.tight_layout()
plt.show()
